from tests.test_request_post import *

if __name__ == '__main__':
    unittest.main()
